`teaching.bb-ai.net/KRR/Prover9`

## Challenging Logic Exercises for Prover9

This is a set of more challenging problems that is intended to sharpen your analytic skills and deepen your understanding of first-order logic representations and proofs.

### The Problems:

1. Parts and Overlaps (10 marks)
2. Honey Crumpets (32 marks)
3. Impostors on a ship (28 marks)

Total marks available: 70

Gradescope
If you are taking one of Brandon's KRR modules, your solutions can be checked and marked automatically using software that has been implemented by embedding Prover9 within the Gradescope platform. Follow the link to Gradescope on the 'Submit My Work' page of the module's Minerva web pages, and look for the assignment: Challenging Logic Exercises